/**
 * Example loading native libraries from the same folder as the library JAR
 *
 * @author Matthias Ringwald freckle@users.sourceforge.net
 */
import java.io.File;

public class A {
    public static File getJarFileFromClasspath(String jarName){
        // get and split CLASSPATH
        String classpath = System.getProperty("java.class.path");
        String[] classPathItems = classpath.split(File.pathSeparator);
        // search for File with jarName
        for (int x=0; x<classPathItems.length; x++) {
            File itemFile = new File (classPathItems[x]);
            // exists?
            if (itemFile.exists() == false){
                continue;
            }
            File absoluteFile = itemFile.getAbsoluteFile();
            if (absoluteFile.getName().equalsIgnoreCase(jarName)){
                return absoluteFile;
            }
        }
        return null;
    }

    public static void main(String args[]) {
        File jarFile = getJarFileFromClasspath("A.jar");
        if (jarFile != null){
            System.out.println("Path: "+jarFile.getAbsolutePath());
            File libFolder = jarFile.getParentFile();
            String libName  = System.mapLibraryName("foo");
            File fooFile = new File( libFolder, libName);
            try {
                System.load( fooFile.getAbsolutePath() );
                printFoo();
                printBar();
            } catch (Exception e) {
                System.out.println(e.toString());
            }
        }
    }
    
    public native static void  printFoo();
    public native static void  printBar();
}
